	.file	"optimize.c"
	.text
	.p2align 4,,15
.globl set_row_1
	.type	set_row_1, @function
set_row_1:
.LFB2:
	xorl	%r8d, %r8d
	cmpq	%rcx, %r8
	jge	.L7
	imulq	%rcx, %rdx
	leaq	(%rdi,%rdx,8), %rdx
	.p2align 4,,7
.L5:
	movq	(%rsi,%r8,8), %rax
	incq	%r8
	movq	%rax, (%rdx)
	addq	$8, %rdx
	cmpq	%rcx, %r8
	jl	.L5
.L7:
	rep ; ret
.LFE2:
	.size	set_row_1, .-set_row_1
	.p2align 4,,15
.globl set_row_2
	.type	set_row_2, @function
set_row_2:
.LFB3:
	xorl	%r8d, %r8d
	imulq	%rcx, %rdx
	cmpq	%rcx, %r8
	jge	.L15
	leaq	(%rdi,%rdx,8), %rdx
	.p2align 4,,7
.L13:
	movq	(%rsi,%r8,8), %rax
	incq	%r8
	movq	%rax, (%rdx)
	addq	$8, %rdx
	cmpq	%rcx, %r8
	jl	.L13
.L15:
	rep ; ret
.LFE3:
	.size	set_row_2, .-set_row_2
	.p2align 4,,15
.globl lower_1
	.type	lower_1, @function
lower_1:
.LFB4:
	pushq	%r12
.LCFI0:
	xorl	%r12d, %r12d
	pushq	%rbp
.LCFI1:
	movq	%rdi, %rbp
	pushq	%rbx
.LCFI2:
	movslq	%r12d,%rbx
	movq	%rbp, %rdi
	call	strlen
	cmpq	%rax, %rbx
	jae	.L22
	.p2align 4,,7
.L21:
	movzbl	(%rbx,%rbp), %edx
	leal	-65(%rdx), %eax
	cmpb	$25, %al
	ja	.L19
	leal	32(%rdx), %eax
	movb	%al, (%rbx,%rbp)
.L19:
	incl	%r12d
	movq	%rbp, %rdi
	movslq	%r12d,%rbx
	call	strlen
	cmpq	%rax, %rbx
	jb	.L21
.L22:
	popq	%rbx
	popq	%rbp
	popq	%r12
	ret
.LFE4:
	.size	lower_1, .-lower_1
	.p2align 4,,15
.globl lower_2
	.type	lower_2, @function
lower_2:
.LFB5:
	pushq	%rbx
.LCFI3:
	movq	%rdi, %rbx
	call	strlen
	xorl	%esi, %esi
	movl	%eax, %edi
	cmpl	%edi, %esi
	jge	.L30
	.p2align 4,,7
.L32:
	movslq	%esi,%rcx
	movzbl	(%rcx,%rbx), %edx
	leal	-65(%rdx), %eax
	cmpb	$25, %al
	ja	.L26
	leal	32(%rdx), %eax
	movb	%al, (%rcx,%rbx)
.L26:
	incl	%esi
	cmpl	%edi, %esi
	jl	.L32
.L30:
	popq	%rbx
	ret
.LFE5:
	.size	lower_2, .-lower_2
	.p2align 4,,15
.globl lower_3
	.type	lower_3, @function
lower_3:
.LFB6:
	xorl	%esi, %esi
	.p2align 4,,7
.L38:
	movslq	%esi,%rcx
	movzbl	(%rcx,%rdi), %edx
	leal	-65(%rdx), %eax
	cmpb	$25, %al
	ja	.L36
	leal	32(%rdx), %eax
	movb	%al, (%rcx,%rdi)
.L36:
	incl	%esi
	testb	%dl, %dl
	jne	.L38
	rep ; ret
.LFE6:
	.size	lower_3, .-lower_3
	.p2align 4,,15
.globl lower_4
	.type	lower_4, @function
lower_4:
.LFB7:
	xorl	%esi, %esi
	.p2align 4,,7
.L46:
	movslq	%esi,%rcx
	movzbl	(%rcx,%rdi), %edx
	leal	-65(%rdx), %eax
	cmpb	$25, %al
	ja	.L44
	leal	-32(%rdx), %eax
	movb	%al, (%rcx,%rdi)
.L44:
	incl	%esi
	testb	%dl, %dl
	jne	.L46
	rep ; ret
.LFE7:
	.size	lower_4, .-lower_4
	.section	.rodata.cst8,"aM",@progbits,8
	.align 8
.LC2:
	.long	0
	.long	1075052544
	.align 8
.LC3:
	.long	0
	.long	1075970048
	.text
	.p2align 4,,15
.globl blur_1
	.type	blur_1, @function
blur_1:
.LFB8:
	leaq	-1(%rdx), %r9
	pushq	%rbx
.LCFI4:
	movl	$1, %eax
	movq	%rdx, %rbx
	cmpq	$1, %r9
	jle	.L59
	movlpd	.LC2(%rip), %xmm4
	movlpd	.LC3(%rip), %xmm3
	.p2align 4,,7
.L57:
	cmpq	$1, %r9
	movl	$1, %r8d
	leaq	1(%rax), %r11
	jle	.L61
	leaq	-1(%rax), %rdx
	movq	%rax, %r10
	movq	%r11, %rax
	imulq	%rbx, %rax
	movsd	%xmm4, %xmm2
	movsd	%xmm3, %xmm1
	imulq	%rbx, %rdx
	imulq	%rbx, %r10
	leaq	8(%rdi,%rax,8), %rcx
	leaq	8(%rdi,%rdx,8), %rdx
	.p2align 4,,7
.L56:
	leaq	(%r10,%r8), %rax
	incq	%r8
	movlpd	(%rdi,%rax,8), %xmm0
	mulsd	%xmm2, %xmm0
	addsd	(%rdx), %xmm0
	addq	$8, %rdx
	addsd	-8(%rdi,%rax,8), %xmm0
	addsd	(%rcx), %xmm0
	addq	$8, %rcx
	cmpq	%r8, %r9
	addsd	8(%rdi,%rax,8), %xmm0
	divsd	%xmm1, %xmm0
	movsd	%xmm0, (%rsi,%rax,8)
	jg	.L56
.L61:
	cmpq	%r11, %r9
	movq	%r11, %rax
	jg	.L57
.L59:
	popq	%rbx
	ret
.LFE8:
	.size	blur_1, .-blur_1
	.section	.rodata.cst8
	.align 8
.LC6:
	.long	0
	.long	1075052544
	.align 8
.LC7:
	.long	0
	.long	1075970048
	.text
	.p2align 4,,15
.globl blur_2
	.type	blur_2, @function
blur_2:
.LFB9:
	leaq	-1(%rdx), %r8
	movl	$1, %r10d
	cmpq	$1, %r8
	jle	.L73
	movq	%rdx, %rcx
	.p2align 4,,7
.L71:
	movl	$1, %eax
	cmpq	$1, %r8
	jmp	.L76
	.p2align 4,,7
.L77:
	leaq	(%rcx,%rax), %r9
	incq	%rax
	cmpq	%rax, %r8
.L76:
	jg	.L77
	incq	%r10
	addq	%rdx, %rcx
	cmpq	%r10, %r8
	jg	.L71
.L73:
	movlpd	.LC6(%rip), %xmm0
	movq	%r9, %rax
	subq	%rdx, %rax
	mulsd	(%rdi,%r9,8), %xmm0
	addsd	(%rdi,%rax,8), %xmm0
	leaq	(%r9,%rdx), %rax
	addsd	-8(%rdi,%r9,8), %xmm0
	addsd	(%rdi,%rax,8), %xmm0
	addsd	8(%rdi,%r9,8), %xmm0
	divsd	.LC7(%rip), %xmm0
	movsd	%xmm0, (%rsi,%r9,8)
	ret
.LFE9:
	.size	blur_2, .-blur_2
	.section	.eh_frame,"a",@progbits
.Lframe1:
	.long	.LECIE1-.LSCIE1
.LSCIE1:
	.long	0x0
	.byte	0x1
	.string	""
	.uleb128 0x1
	.sleb128 -8
	.byte	0x10
	.byte	0xc
	.uleb128 0x7
	.uleb128 0x8
	.byte	0x90
	.uleb128 0x1
	.align 8
.LECIE1:
.LSFDE1:
	.long	.LEFDE1-.LASFDE1
.LASFDE1:
	.long	.LASFDE1-.Lframe1
	.quad	.LFB2
	.quad	.LFE2-.LFB2
	.align 8
.LEFDE1:
.LSFDE3:
	.long	.LEFDE3-.LASFDE3
.LASFDE3:
	.long	.LASFDE3-.Lframe1
	.quad	.LFB3
	.quad	.LFE3-.LFB3
	.align 8
.LEFDE3:
.LSFDE5:
	.long	.LEFDE5-.LASFDE5
.LASFDE5:
	.long	.LASFDE5-.Lframe1
	.quad	.LFB4
	.quad	.LFE4-.LFB4
	.byte	0x4
	.long	.LCFI0-.LFB4
	.byte	0xe
	.uleb128 0x10
	.byte	0x8c
	.uleb128 0x2
	.byte	0x4
	.long	.LCFI1-.LCFI0
	.byte	0xe
	.uleb128 0x18
	.byte	0x86
	.uleb128 0x3
	.byte	0x4
	.long	.LCFI2-.LCFI1
	.byte	0xe
	.uleb128 0x20
	.byte	0x83
	.uleb128 0x4
	.align 8
.LEFDE5:
.LSFDE7:
	.long	.LEFDE7-.LASFDE7
.LASFDE7:
	.long	.LASFDE7-.Lframe1
	.quad	.LFB5
	.quad	.LFE5-.LFB5
	.byte	0x4
	.long	.LCFI3-.LFB5
	.byte	0xe
	.uleb128 0x10
	.byte	0x83
	.uleb128 0x2
	.align 8
.LEFDE7:
.LSFDE9:
	.long	.LEFDE9-.LASFDE9
.LASFDE9:
	.long	.LASFDE9-.Lframe1
	.quad	.LFB6
	.quad	.LFE6-.LFB6
	.align 8
.LEFDE9:
.LSFDE11:
	.long	.LEFDE11-.LASFDE11
.LASFDE11:
	.long	.LASFDE11-.Lframe1
	.quad	.LFB7
	.quad	.LFE7-.LFB7
	.align 8
.LEFDE11:
.LSFDE13:
	.long	.LEFDE13-.LASFDE13
.LASFDE13:
	.long	.LASFDE13-.Lframe1
	.quad	.LFB8
	.quad	.LFE8-.LFB8
	.byte	0x4
	.long	.LCFI4-.LFB8
	.byte	0xe
	.uleb128 0x10
	.byte	0x83
	.uleb128 0x2
	.align 8
.LEFDE13:
.LSFDE15:
	.long	.LEFDE15-.LASFDE15
.LASFDE15:
	.long	.LASFDE15-.Lframe1
	.quad	.LFB9
	.quad	.LFE9-.LFB9
	.align 8
.LEFDE15:
	.section	.note.GNU-stack,"",@progbits
	.ident	"GCC: (GNU) 3.4.2 20041017 (Red Hat 3.4.2-6.fc3)"
