	.file	"optimize.c"
	.text
.globl set_row_1
	.type	set_row_1, @function
set_row_1:
.LFB2:
	movl	$0, %r8d
	cmpq	%rcx, %r8
	jge	.L7
	movq	%rdx, %r9
	imulq	%rcx, %r9
.L5:
	leaq	(%r9,%r8), %rdx
	movq	(%rsi,%r8,8), %rax
	movq	%rax, (%rdi,%rdx,8)
	incq	%r8
	cmpq	%rcx, %r8
	jl	.L5
.L7:
	rep ; ret
.LFE2:
	.size	set_row_1, .-set_row_1
.globl set_row_2
	.type	set_row_2, @function
set_row_2:
.LFB3:
	movq	%rdx, %r9
	imulq	%rcx, %r9
	movl	$0, %r8d
	cmpq	%rcx, %r8
	jge	.L14
.L12:
	leaq	(%r9,%r8), %rdx
	movq	(%rsi,%r8,8), %rax
	movq	%rax, (%rdi,%rdx,8)
	incq	%r8
	cmpq	%rcx, %r8
	jl	.L12
.L14:
	rep ; ret
.LFE3:
	.size	set_row_2, .-set_row_2
.globl lower_1
	.type	lower_1, @function
lower_1:
.LFB4:
	movq	%rdi, %rsi
	movl	$0, %r8d
	cld
	movq	$-1, %rcx
	movl	$0, %eax
	repnz
	scasb
	cmpq	$-2, %rcx
	je	.L22
	movq	$-1, %r10
	movl	$0, %r9d
.L20:
	movslq	%r8d,%rcx
	movzbl	(%rcx,%rsi), %edx
	leal	-65(%rdx), %eax
	cmpb	$25, %al
	ja	.L18
	leal	32(%rdx), %eax
	movb	%al, (%rcx,%rsi)
.L18:
	incl	%r8d
	movslq	%r8d,%rdx
	movq	%rsi, %rdi
	movq	%r10, %rcx
	movl	%r9d, %eax
	repnz
	scasb
	notq	%rcx
	decq	%rcx
	cmpq	%rcx, %rdx
	jb	.L20
.L22:
	rep ; ret
.LFE4:
	.size	lower_1, .-lower_1
.globl lower_2
	.type	lower_2, @function
lower_2:
.LFB5:
	movq	%rdi, %r9
	cld
	movq	$-1, %rcx
	movl	$0, %eax
	repnz
	scasb
	notq	%rcx
	decl	%ecx
	movl	$0, %r8d
	cmpl	%ecx, %r8d
	jge	.L30
.L28:
	movslq	%r8d,%rsi
	movzbl	(%rsi,%r9), %edx
	leal	-65(%rdx), %eax
	cmpb	$25, %al
	ja	.L26
	leal	32(%rdx), %eax
	movb	%al, (%rsi,%r9)
.L26:
	incl	%r8d
	cmpl	%ecx, %r8d
	jl	.L28
.L30:
	rep ; ret
.LFE5:
	.size	lower_2, .-lower_2
.globl lower_3
	.type	lower_3, @function
lower_3:
.LFB6:
	movl	$0, %esi
.L36:
	movslq	%esi,%rcx
	movzbl	(%rcx,%rdi), %edx
	leal	-65(%rdx), %eax
	cmpb	$25, %al
	ja	.L34
	leal	32(%rdx), %eax
	movb	%al, (%rcx,%rdi)
.L34:
	incl	%esi
	testb	%dl, %dl
	jne	.L36
	rep ; ret
.LFE6:
	.size	lower_3, .-lower_3
.globl lower_4
	.type	lower_4, @function
lower_4:
.LFB7:
	movl	$0, %esi
.L44:
	movslq	%esi,%rcx
	movzbl	(%rcx,%rdi), %edx
	leal	-65(%rdx), %eax
	cmpb	$25, %al
	ja	.L42
	leal	-32(%rdx), %eax
	movb	%al, (%rcx,%rdi)
.L42:
	incl	%esi
	testb	%dl, %dl
	jne	.L44
	rep ; ret
.LFE7:
	.size	lower_4, .-lower_4
	.section	.rodata.cst4,"aM",@progbits,4
	.align 4
.LC0:
	.long	1084227584
	.align 4
.LC1:
	.long	1091567616
	.text
.globl blur_1
	.type	blur_1, @function
blur_1:
.LFB8:
	pushq	%r12
.LCFI0:
	pushq	%rbp
.LCFI1:
	pushq	%rbx
.LCFI2:
	movq	%rdx, %rbp
	movl	$1, %ebx
	leaq	-1(%rdx), %rax
	movq	%rax, %rdx
	cmpq	$1, %rax
	jle	.L57
	cvtss2sd	.LC0(%rip), %xmm3
	cvtss2sd	.LC1(%rip), %xmm4
	movq	%rax, %r12
.L55:
	movl	$1, %ecx
	movq	%rdx, %r11
	cmpq	$1, %rdx
	jle	.L59
	movq	%rbx, %r10
	imulq	%rbp, %r10
	movsd	%xmm3, %xmm2
	leaq	-1(%rbx), %rax
	movq	%rax, %r9
	imulq	%rbp, %r9
	leaq	1(%rbx), %rax
	movq	%rax, %r8
	imulq	%rbp, %r8
	movsd	%xmm4, %xmm1
.L54:
	leaq	(%r10,%rcx), %rdx
	movlpd	(%rdi,%rdx,8), %xmm0
	mulsd	%xmm2, %xmm0
	leaq	(%r9,%rcx), %rax
	addsd	(%rdi,%rax,8), %xmm0
	addsd	-8(%rdi,%rdx,8), %xmm0
	leaq	(%r8,%rcx), %rax
	addsd	(%rdi,%rax,8), %xmm0
	addsd	8(%rdi,%rdx,8), %xmm0
	divsd	%xmm1, %xmm0
	movsd	%xmm0, (%rsi,%rdx,8)
	incq	%rcx
	cmpq	%rcx, %r11
	jg	.L54
.L59:
	incq	%rbx
	movq	%r12, %rdx
	cmpq	%rbx, %r12
	jg	.L55
.L57:
	popq	%rbx
	popq	%rbp
	popq	%r12
	ret
.LFE8:
	.size	blur_1, .-blur_1
	.section	.rodata.cst8,"aM",@progbits,8
	.align 8
.LC6:
	.long	0
	.long	1075052544
	.align 8
.LC7:
	.long	0
	.long	1075970048
	.text
.globl blur_2
	.type	blur_2, @function
blur_2:
.LFB9:
	movl	$1, %r10d
	leaq	-1(%rdx), %rax
	movq	%rax, %r8
	cmpq	$1, %rax
	jle	.L70
	movq	%rax, %r11
.L68:
	movl	$1, %ecx
	movq	%r8, %rax
	cmpq	$1, %rax
	jle	.L72
	movq	%rdx, %rax
	imulq	%r10, %rax
.L67:
	leaq	(%rax,%rcx), %r9
	incq	%rcx
	cmpq	%rcx, %r8
	jg	.L67
.L72:
	incq	%r10
	movq	%r11, %r8
	cmpq	%r10, %r11
	jg	.L68
.L70:
	movlpd	.LC6(%rip), %xmm0
	mulsd	(%rdi,%r9,8), %xmm0
	movq	%r9, %rax
	subq	%rdx, %rax
	addsd	(%rdi,%rax,8), %xmm0
	addsd	-8(%rdi,%r9,8), %xmm0
	leaq	(%r9,%rdx), %rax
	addsd	(%rdi,%rax,8), %xmm0
	addsd	8(%rdi,%r9,8), %xmm0
	divsd	.LC7(%rip), %xmm0
	movsd	%xmm0, (%rsi,%r9,8)
	ret
.LFE9:
	.size	blur_2, .-blur_2
	.section	.eh_frame,"a",@progbits
.Lframe1:
	.long	.LECIE1-.LSCIE1
.LSCIE1:
	.long	0x0
	.byte	0x1
	.string	""
	.uleb128 0x1
	.sleb128 -8
	.byte	0x10
	.byte	0xc
	.uleb128 0x7
	.uleb128 0x8
	.byte	0x90
	.uleb128 0x1
	.align 8
.LECIE1:
.LSFDE1:
	.long	.LEFDE1-.LASFDE1
.LASFDE1:
	.long	.LASFDE1-.Lframe1
	.quad	.LFB2
	.quad	.LFE2-.LFB2
	.align 8
.LEFDE1:
.LSFDE3:
	.long	.LEFDE3-.LASFDE3
.LASFDE3:
	.long	.LASFDE3-.Lframe1
	.quad	.LFB3
	.quad	.LFE3-.LFB3
	.align 8
.LEFDE3:
.LSFDE5:
	.long	.LEFDE5-.LASFDE5
.LASFDE5:
	.long	.LASFDE5-.Lframe1
	.quad	.LFB4
	.quad	.LFE4-.LFB4
	.align 8
.LEFDE5:
.LSFDE7:
	.long	.LEFDE7-.LASFDE7
.LASFDE7:
	.long	.LASFDE7-.Lframe1
	.quad	.LFB5
	.quad	.LFE5-.LFB5
	.align 8
.LEFDE7:
.LSFDE9:
	.long	.LEFDE9-.LASFDE9
.LASFDE9:
	.long	.LASFDE9-.Lframe1
	.quad	.LFB6
	.quad	.LFE6-.LFB6
	.align 8
.LEFDE9:
.LSFDE11:
	.long	.LEFDE11-.LASFDE11
.LASFDE11:
	.long	.LASFDE11-.Lframe1
	.quad	.LFB7
	.quad	.LFE7-.LFB7
	.align 8
.LEFDE11:
.LSFDE13:
	.long	.LEFDE13-.LASFDE13
.LASFDE13:
	.long	.LASFDE13-.Lframe1
	.quad	.LFB8
	.quad	.LFE8-.LFB8
	.byte	0x4
	.long	.LCFI0-.LFB8
	.byte	0xe
	.uleb128 0x10
	.byte	0x4
	.long	.LCFI1-.LCFI0
	.byte	0xe
	.uleb128 0x18
	.byte	0x4
	.long	.LCFI2-.LCFI1
	.byte	0xe
	.uleb128 0x20
	.byte	0x83
	.uleb128 0x4
	.byte	0x86
	.uleb128 0x3
	.byte	0x8c
	.uleb128 0x2
	.align 8
.LEFDE13:
.LSFDE15:
	.long	.LEFDE15-.LASFDE15
.LASFDE15:
	.long	.LASFDE15-.Lframe1
	.quad	.LFB9
	.quad	.LFE9-.LFB9
	.align 8
.LEFDE15:
	.section	.note.GNU-stack,"",@progbits
	.ident	"GCC: (GNU) 3.4.2 20041017 (Red Hat 3.4.2-6.fc3)"
